Capabilities

Struct Capabilities 

pub struct Capabilities(/* private fields */);
Allowed IR capabilities.

Implementations

Source

impl Capabilities

pub const IMMEDIATES: Self

pub const FLOAT64: Self

Float values with width = 8.

pub const PRIMITIVE_INDEX: Self

pub const TEXTURE_AND_SAMPLER_BINDING_ARRAY: Self

Support for binding arrays of sampled textures and samplers.

pub const BUFFER_BINDING_ARRAY: Self

Support for binding arrays of uniform buffers.

pub const STORAGE_TEXTURE_BINDING_ARRAY: Self

Support for binding arrays of storage textures.

pub const STORAGE_BUFFER_BINDING_ARRAY: Self

Support for binding arrays of storage buffers.

pub const CLIP_DISTANCE: Self

Support for BuiltIn::ClipDistance.

pub const CULL_DISTANCE: Self

Support for BuiltIn::CullDistance.

pub const STORAGE_TEXTURE_16BIT_NORM_FORMATS: Self

Support for 16-bit normalized storage texture formats.

pub const MULTIVIEW: Self

Support for BuiltIn::ViewIndex.

pub const EARLY_DEPTH_TEST: Self

Support for early_depth_test.

pub const MULTISAMPLED_SHADING: Self

pub const RAY_QUERY: Self

Support for ray queries and acceleration structures.

pub const DUAL_SOURCE_BLENDING: Self

Support for generating two sources for blending from fragment shaders.

pub const CUBE_ARRAY_TEXTURES: Self

Support for arrayed cube textures.

pub const SHADER_INT64: Self

Support for 64-bit signed and unsigned integers.

pub const SUBGROUP: Self

Support for subgroup operations (except barriers) in fragment and compute shaders.

Subgroup operations in the vertex stage require Capabilities::SUBGROUP_VERTEX_STAGE in addition to Capabilities::SUBGROUP. (But note that create_validator automatically sets Capabilities::SUBGROUP whenever Features::SUBGROUP_VERTEX is available.)

Subgroup barriers require Capabilities::SUBGROUP_BARRIER in addition to Capabilities::SUBGROUP.

pub const SUBGROUP_BARRIER: Self

Support for subgroup barriers in compute shaders.

Requires Capabilities::SUBGROUP. Without it, enables nothing.

pub const SUBGROUP_VERTEX_STAGE: Self

Support for subgroup operations (not including barriers) in the vertex stage.

Without Capabilities::SUBGROUP, enables nothing. (But note that create_validator automatically sets Capabilities::SUBGROUP whenever Features::SUBGROUP_VERTEX is available.)

pub const SHADER_INT64_ATOMIC_MIN_MAX: Self

Support for AtomicFunction::Min and AtomicFunction::Max on 64-bit integers in the Storage address space, when the return value is not used.

This is the only 64-bit atomic functionality available on Metal 3.1.

pub const SHADER_INT64_ATOMIC_ALL_OPS: Self

Support for all atomic operations on 64-bit integers.

pub const SHADER_FLOAT32_ATOMIC: Self

Support for AtomicFunction::Add, AtomicFunction::Sub, and AtomicFunction::Exchange { compare: None } on 32-bit floating-point numbers in the Storage address space.

pub const TEXTURE_ATOMIC: Self

Support for atomic operations on images.

pub const TEXTURE_INT64_ATOMIC: Self

Support for atomic operations on 64-bit images.

pub const RAY_HIT_VERTEX_POSITION: Self

Support for ray queries returning vertex position

pub const SHADER_FLOAT16: Self

Support for 16-bit floating-point types.

pub const TEXTURE_EXTERNAL: Self

Support for [ImageClass::External]

pub const SHADER_FLOAT16_IN_FLOAT32: Self

Support for quantizeToF16, pack2x16float, and unpack2x16float, which store f16-precision values in f32s.

pub const SHADER_BARYCENTRICS: Self

Support for fragment shader barycentric coordinates.

pub const MESH_SHADER: Self

Support for task shaders, mesh shaders, and per-primitive fragment inputs

pub const MESH_SHADER_POINT_TOPOLOGY: Self

Support for mesh shaders which output points.

pub const TEXTURE_AND_SAMPLER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Self

Support for non-uniform indexing of binding arrays of sampled textures and samplers.

pub const BUFFER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Self

Support for non-uniform indexing of binding arrays of uniform buffers.

pub const STORAGE_TEXTURE_BINDING_ARRAY_NON_UNIFORM_INDEXING: Self

Support for non-uniform indexing of binding arrays of storage textures.

pub const STORAGE_BUFFER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Self

Support for non-uniform indexing of binding arrays of storage buffers.

pub const COOPERATIVE_MATRIX: Self

Support for cooperative matrix types and operations

pub const PER_VERTEX: Self

Support for per-vertex fragment input.

pub const RAY_TRACING_PIPELINE: Self

Support for ray generation, any hit, closest hit, and miss shaders.

pub const DRAW_INDEX: Self

Support for draw index builtin

pub const ACCELERATION_STRUCTURE_BINDING_ARRAY: Self

Support for binding arrays of acceleration structures.

pub const MEMORY_DECORATION_COHERENT: Self

Support for the @coherent memory decoration on storage buffers.

pub const MEMORY_DECORATION_VOLATILE: Self

Support for the @volatile memory decoration on storage buffers.

Source

impl Capabilities

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl Capabilities

pub const fn iter(&self) -> Iter<Capabilities>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Capabilities>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.